Index: wp-admin/edit-comments.php
===================================================================
--- wp-admin/edit-comments.php	(revision 3877)
+++ wp-admin/edit-comments.php	(working copy)
@@ -45,7 +45,7 @@
   <input type="text" name="s" value="<?php if (isset($_GET['s'])) echo wp_specialchars($_GET['s'], 1); ?>" size="17" /> 
   <input type="submit" name="submit" value="<?php _e('Search') ?>"  />  
   <input type="hidden" name="mode" value="<?php echo $mode; ?>" />
-  <?php _e('(Searches within comment text, e-mail, URI, and IP address.)') ?>
+  <?php _e('(Searches within comment text, e-mail, URL, and IP address.)') ?>
   </fieldset> 
 </form>
 <p><a href="?mode=view"><?php _e('View Mode') ?></a> | <a href="?mode=edit"><?php _e('Mass Edit Mode') ?></a></p>
Index: wp-admin/edit-form-advanced.php
===================================================================
--- wp-admin/edit-form-advanced.php	(revision 3877)
+++ wp-admin/edit-form-advanced.php	(working copy)
@@ -191,7 +191,7 @@
 
 <fieldset class="dbx-box">
 <h3 class="dbx-handle"><?php _e('Trackbacks') ?></h3>
-<div class="dbx-content"><?php _e('Send trackbacks to'); ?>: <?php echo $form_trackback; ?> (<?php _e('Separate multiple URIs with spaces'); ?>)
+<div class="dbx-content"><?php _e('Send trackbacks to'); ?>: <?php echo $form_trackback; ?> (<?php _e('Separate multiple <abbr title="Universal Resource Locator">URL</abbr>s with spaces'); ?>)
 <?php 
 if ( ! empty($pings) )
 	echo $pings;
Index: wp-admin/edit-form-comment.php
===================================================================
--- wp-admin/edit-form-comment.php	(revision 3877)
+++ wp-admin/edit-form-comment.php	(working copy)
@@ -30,7 +30,7 @@
     </div>
 </fieldset>
 <fieldset id="uridiv">
-        <legend><label for="URL"><?php _e('URI:') ?></label></legend>
+        <legend><label for="URL"><?php _e('URL:') ?></label></legend>
 		<div>
 		  <input type="text" id="newcomment_author_url" name="newcomment_author_url" size="35" value="<?php echo $comment->comment_author_url ?>" tabindex="3" id="URL" />
     </div>
Index: wp-admin/edit-form.php
===================================================================
--- wp-admin/edit-form.php	(revision 3877)
+++ wp-admin/edit-form.php	(working copy)
@@ -51,7 +51,7 @@
 
 <input type="hidden" name="post_pingback" value="<?php echo get_option('default_pingback_flag') ?>" id="post_pingback" />
 
-<p><label for="trackback"> <?php printf(__('<a href="%s" title="Help on trackbacks"><strong>TrackBack</strong> a <abbr title="Universal Resource Identifier">URI</abbr></a>:</label> (Separate multiple <abbr title="Universal Resource Identifier">URI</abbr>s with spaces.)<br />'), 'http://wordpress.org/docs/reference/post/#trackback') ?>
+<p><label for="trackback"> <?php printf(__('<a href="%s" title="Help on trackbacks"><strong>TrackBack</strong> a <abbr title="Universal Resource Locator">URL</abbr></a>:</label> (Separate multiple <abbr title="Universal Resource Locator">URL</abbr>s with spaces.)<br />'), 'http://wordpress.org/docs/reference/post/#trackback') ?>
 	<input type="text" name="trackback_url" style="width: 360px" id="trackback" tabindex="7" /></p>
 
 <p class="submit"><input name="saveasdraft" type="submit" id="saveasdraft" tabindex="9" value="<?php _e('Save as Draft') ?>" /> 
Index: wp-admin/edit-link-form.php
===================================================================
--- wp-admin/edit-link-form.php	(revision 3877)
+++ wp-admin/edit-link-form.php	(working copy)
@@ -79,7 +79,7 @@
 
 <table class="editform" width="100%" cellspacing="2" cellpadding="5">
 <tr>
-<th width="20%" scope="row" valign="top"><label for="link_url"><?php _e('URI:') ?></label></th>
+<th width="20%" scope="row" valign="top"><label for="link_url"><?php _e('URL:') ?></label></th>
 <td width="80%"><input type="text" name="link_url" value="<?php echo $link->link_url; ?>" style="width: 95%" /></td>
 </tr>
 <tr>
@@ -216,11 +216,11 @@
 <div class="dbx-content">
 <table class="editform" width="100%" cellspacing="2" cellpadding="5">
 	<tr>
-		<th width="20%" scope="row"><?php _e('Image URI:') ?></th>
+		<th width="20%" scope="row"><?php _e('Image URL:') ?></th>
 		<td width="80%"><input type="text" name="link_image" size="50" value="<?php echo $link->link_image; ?>" style="width: 95%" /></td>
 	</tr>
 	<tr>
-		<th scope="row"><?php _e('RSS URI:') ?> </th>
+		<th scope="row"><?php _e('RSS URL:') ?> </th>
 		<td><input name="link_rss" type="text" id="rss_uri" value="<?php echo $link->link_rss; ?>" size="50" style="width: 95%" /></td>
 	</tr>
 	<tr>
Index: wp-admin/link-manager.php
===================================================================
--- wp-admin/link-manager.php	(revision 3877)
+++ wp-admin/link-manager.php	(working copy)
@@ -104,7 +104,7 @@
 <select name="order_by">
 <option value="order_id" <?php if ($order_by == 'order_id') echo " selected='selected'";?>><?php _e('Bookmark ID') ?></option>
 <option value="order_name" <?php if ($order_by == 'order_name') echo " selected='selected'";?>><?php _e('Name') ?></option>
-<option value="order_url" <?php if ($order_by == 'order_url') echo " selected='selected'";?>><?php _e('URI') ?></option>
+<option value="order_url" <?php if ($order_by == 'order_url') echo " selected='selected'";?>><?php _e('URL') ?></option>
 </select>
 <input type="submit" name="action" value="<?php _e('Update &raquo;') ?>" />
 </form>
@@ -119,7 +119,7 @@
 	<thead>
 	<tr>
 		<th width="15%" style="text-align: left"><?php _e('Name') ?></th>
-		<th style="text-align: left"><?php _e('URI') ?></th>
+		<th style="text-align: left"><?php _e('URL') ?></th>
 		<th style="text-align: left"><?php _e('Categories') ?></th>
 		<th><?php _e('rel') ?></th>
 		<th><?php _e('Visible') ?></th>
Index: wp-admin/options-discussion.php
===================================================================
--- wp-admin/options-discussion.php	(revision 3877)
+++ wp-admin/options-discussion.php	(working copy)
@@ -73,7 +73,7 @@
 <legend><?php _e('Comment Moderation') ?></legend>
 <p><?php printf(__('Hold a comment in the queue if it contains more than %s links. (A common characteristic of comment spam is a large number of hyperlinks.)'), '<input name="comment_max_links" type="text" id="comment_max_links" size="3" value="' . get_settings('comment_max_links'). '" />' ) ?></p>
 
-<p><?php _e('When a comment contains any of these words in its content, name, URI, e-mail, or IP, hold it in the moderation queue: (Separate multiple words with new lines.) <a href="http://codex.wordpress.org/Spam_Words">Common spam words</a>.') ?></p>
+<p><?php _e('When a comment contains any of these words in its content, name, URL, e-mail, or IP, hold it in the moderation queue: (Separate multiple words with new lines.) <a href="http://codex.wordpress.org/Spam_Words">Common spam words</a>.') ?></p>
 <p> 
 <textarea name="moderation_keys" cols="60" rows="4" id="moderation_keys" style="width: 98%; font-size: 12px;" class="code"><?php form_option('moderation_keys'); ?></textarea> 
 </p> 
Index: wp-admin/options-general.php
===================================================================
--- wp-admin/options-general.php	(revision 3877)
+++ wp-admin/options-general.php	(working copy)
@@ -23,11 +23,11 @@
 <?php _e('In a few words, explain what this weblog is about.') ?></td> 
 </tr> 
 <tr valign="top"> 
-<th scope="row"><?php _e('WordPress address (URI):') ?></th> 
+<th scope="row"><?php _e('WordPress address (URL):') ?></th> 
 <td><input name="siteurl" type="text" id="siteurl" value="<?php form_option('siteurl'); ?>" size="40" class="code" /></td> 
 </tr> 
 <tr valign="top">
-<th scope="row"><?php _e('Blog address (URI):') ?></th>
+<th scope="row"><?php _e('Blog address (URL):') ?></th>
 <td><input name="home" type="text" id="home" value="<?php form_option('home'); ?>" size="40" class="code" /><br /><?php _e('If you want your blog homepage <a href="http://codex.wordpress.org/Giving_WordPress_Its_Own_Directory">to be different than the directory</a> you installed WordPress in, enter that address here.'); ?></td>
 </tr>
 <tr valign="top"> 
Index: wp-admin/options-permalink.php
===================================================================
--- wp-admin/options-permalink.php	(revision 3877)
+++ wp-admin/options-permalink.php	(working copy)
@@ -102,7 +102,7 @@
 
 <div class="wrap"> 
   <h2><?php _e('Customize Permalink Structure') ?></h2> 
-  <p><?php _e('By default WordPress uses web URIs which have question marks and lots of numbers in them, however WordPress offers you the ability to create a custom URI structure for your permalinks and archives. This can improve the aesthetics, usability, and forward-compatibility of your links. A <a href="http://codex.wordpress.org/Using_Permalinks">number of tags are available</a>, and here are some examples to get you started.'); ?></p>
+  <p><?php _e('By default WordPress uses web <abbr title="Universal Resource Locator">URL</abbr>s which have question marks and lots of numbers in them, however WordPress offers you the ability to create a custom URL structure for your permalinks and archives. This can improve the aesthetics, usability, and forward-compatibility of your links. A <a href="http://codex.wordpress.org/Using_Permalinks">number of tags are available</a>, and here are some examples to get you started.'); ?></p>
 
 <?php
 $prefix = '';
@@ -152,9 +152,9 @@
 
 <h3><?php _e('Optional'); ?></h3>
 <?php if ($is_apache) : ?>
-	<p><?php _e('If you like, you may enter a custom prefix for your category URIs here. For example, <code>/taxonomy/tags</code> would make your category links like <code>http://example.org/taxonomy/tags/uncategorized/</code>. If you leave this blank the default will be used.') ?></p>
+	<p><?php _e('If you like, you may enter a custom prefix for your category <abbr title="Universal Resource Locator">URL</abbr>s here. For example, <code>/taxonomy/tags</code> would make your category links like <code>http://example.org/taxonomy/tags/uncategorized/</code>. If you leave this blank the default will be used.') ?></p>
 <?php else : ?>
-	<p><?php _e('If you like, you may enter a custom prefix for your category URIs here. For example, <code>/index.php/taxonomy/tags</code> would make your category links like <code>http://example.org/index.php/taxonomy/tags/uncategorized/</code>. If you leave this blank the default will be used.') ?></p>
+	<p><?php _e('If you like, you may enter a custom prefix for your category <abbr title="Universal Resource Locator">URL</abbr>s here. For example, <code>/index.php/taxonomy/tags</code> would make your category links like <code>http://example.org/index.php/taxonomy/tags/uncategorized/</code>. If you leave this blank the default will be used.') ?></p>
 <?php endif; ?>
 	<p> 
   <?php _e('Category base'); ?>: <input name="category_base" type="text" class="code"  value="<?php echo $category_base; ?>" size="30" /> 
Index: wp-admin/options-writing.php
===================================================================
--- wp-admin/options-writing.php	(revision 3877)
+++ wp-admin/options-writing.php	(working copy)
@@ -96,7 +96,7 @@
 
 <fieldset class="options">
 <legend><?php _e('Update Services') ?></legend>
-<p><?php _e('When you publish a new post, WordPress automatically notifies the following site update services. For more about this, see <a href="http://codex.wordpress.org/Update_Services">Update Services</a> on the Codex. Separate multiple service URIs with line breaks.') ?></p>
+<p><?php _e('When you publish a new post, WordPress automatically notifies the following site update services. For more about this, see <a href="http://codex.wordpress.org/Update_Services">Update Services</a> on the Codex. Separate multiple service <abbr title="Universal Resource Locator">URL</abbr>s with line breaks.') ?></p>
 
 <textarea name="ping_sites" id="ping_sites" style="width: 98%;" rows="3" cols="50"><?php form_option('ping_sites'); ?></textarea>
 </fieldset>
Index: wp-content/themes/classic/comments-popup.php
===================================================================
--- wp-content/themes/classic/comments-popup.php	(revision 3877)
+++ wp-content/themes/classic/comments-popup.php	(working copy)
@@ -24,7 +24,7 @@
 <p><a href="<?php echo get_settings('siteurl'); ?>/wp-commentsrss2.php?p=<?php echo $post->ID; ?>"><?php _e("<abbr title=\"Really Simple Syndication\">RSS</abbr> feed for comments on this post."); ?></a></p>
 
 <?php if ('open' == $post->ping_status) { ?>
-<p><?php _e("The <acronym title=\"Uniform Resource Identifier\">URI</acronym> to TrackBack this entry is:"); ?> <em><?php trackback_url() ?></em></p>
+<p><?php _e("The <abbr title=\"Universal Resource Locator\">URL</abbr> to TrackBack this entry is:"); ?> <em><?php trackback_url() ?></em></p>
 <?php } ?>
 
 <?php
@@ -71,7 +71,7 @@
 
 	<p>
 	  <input type="text" name="url" id="url" value="<?php echo $comment_author_url; ?>" size="28" tabindex="3" />
-	   <label for="url"><?php _e("<acronym title=\"Uniform Resource Identifier\">URI</acronym>"); ?></label>
+	   <label for="url"><?php _e("<abbr title=\"Universal Resource Locator\">URL</abbr>"); ?></label>
 	</p>
 
 	<p>
Index: wp-content/themes/classic/comments.php
===================================================================
--- wp-content/themes/classic/comments.php	(revision 3877)
+++ wp-content/themes/classic/comments.php	(working copy)
@@ -27,7 +27,7 @@
 
 <p><?php comments_rss_link(__('<abbr title="Really Simple Syndication">RSS</abbr> feed for comments on this post.')); ?> 
 <?php if ( pings_open() ) : ?>
-	<a href="<?php trackback_url() ?>" rel="trackback"><?php _e('TrackBack <abbr title="Uniform Resource Identifier">URI</abbr>'); ?></a>
+	<a href="<?php trackback_url() ?>" rel="trackback"><?php _e('TrackBack <abbr title="Universal Resource Locator">URL</abbr>'); ?></a>
 <?php endif; ?>
 </p>
 
Index: wp-content/themes/default/comments-popup.php
===================================================================
--- wp-content/themes/default/comments-popup.php	(revision 3877)
+++ wp-content/themes/default/comments-popup.php	(working copy)
@@ -24,7 +24,7 @@
 <p><a href="<?php echo get_settings('siteurl'); ?>/wp-commentsrss2.php?p=<?php echo $post->ID; ?>"><abbr title="Really Simple Syndication">RSS</abbr> feed for comments on this post.</a></p>
 
 <?php if ('open' == $post->ping_status) { ?>
-<p>The <acronym title="Uniform Resource Identifier">URI</acronym> to TrackBack this entry is: <em><?php trackback_url() ?></em></p>
+<p>The <abbr title="Universal Resource Locator">URL</abbr> to TrackBack this entry is: <em><?php trackback_url() ?></em></p>
 <?php } ?>
 
 <?php
@@ -71,7 +71,7 @@
 
 	<p>
 	  <input type="text" name="url" id="url" value="<?php echo $comment_author_url; ?>" size="28" tabindex="3" />
-	   <label for="url"><acronym title="Uniform Resource Identifier">URI</acronym></label>
+	   <label for="url"><abbr title="Universal Resource Locator">URL</abbr></label>
 	</p>
 
 	<p>
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 3877)
+++ wp-includes/comment.php	(working copy)
@@ -580,7 +580,7 @@
 			$pingback_href_end = @strpos($contents, $quote, $pingback_href_start);
 			$pingback_server_url_len = $pingback_href_end - $pingback_href_start;
 			$pingback_server_url = substr($contents, $pingback_href_start, $pingback_server_url_len);
-			// We may find rel="pingback" but an incomplete pingback URI
+			// We may find rel="pingback" but an incomplete pingback URL
 			if ($pingback_server_url_len > 0) {
 				// We got it!
 				return $pingback_server_url;
Index: wp-includes/link-template.php
===================================================================
--- wp-includes/link-template.php	(revision 3877)
+++ wp-includes/link-template.php	(working copy)
@@ -398,7 +398,7 @@
 				$qstr = preg_replace("#/*" . $index . "/*#", '/', $qstr);
 			} else {
 				// If using path info style permalinks, make sure the index is in
-				// the URI.
+				// the URL.
 				if ( strpos($qstr, $index) === false )
 					$qstr = '/' . $index . $qstr;
 			}
Index: wp-includes/pluggable.php
===================================================================
--- wp-includes/pluggable.php	(revision 3877)
+++ wp-includes/pluggable.php	(working copy)
@@ -364,7 +364,7 @@
 		$notify_message  = sprintf( __('New comment on your post #%1$s "%2$s"'), $comment->comment_post_ID, $post->post_title ) . "\r\n";
 		$notify_message .= sprintf( __('Author : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
 		$notify_message .= sprintf( __('E-mail : %s'), $comment->comment_author_email ) . "\r\n";
-		$notify_message .= sprintf( __('URI    : %s'), $comment->comment_author_url ) . "\r\n";
+		$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
 		$notify_message .= sprintf( __('Whois  : http://ws.arin.net/cgi-bin/whois.pl?queryinput=%s'), $comment->comment_author_IP ) . "\r\n";
 		$notify_message .= __('Comment: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
 		$notify_message .= __('You can see all comments on this post here: ') . "\r\n";
@@ -372,14 +372,14 @@
 	} elseif ('trackback' == $comment_type) {
 		$notify_message  = sprintf( __('New trackback on your post #%1$s "%2$s"'), $comment->comment_post_ID, $post->post_title ) . "\r\n";
 		$notify_message .= sprintf( __('Website: %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
-		$notify_message .= sprintf( __('URI    : %s'), $comment->comment_author_url ) . "\r\n";
+		$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
 		$notify_message .= __('Excerpt: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
 		$notify_message .= __('You can see all trackbacks on this post here: ') . "\r\n";
 		$subject = sprintf( __('[%1$s] Trackback: "%2$s"'), $blogname, $post->post_title );
 	} elseif ('pingback' == $comment_type) {
 		$notify_message  = sprintf( __('New pingback on your post #%1$s "%2$s"'), $comment->comment_post_ID, $post->post_title ) . "\r\n";
 		$notify_message .= sprintf( __('Website: %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
-		$notify_message .= sprintf( __('URI    : %s'), $comment->comment_author_url ) . "\r\n";
+		$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
 		$notify_message .= __('Excerpt: ') . "\r\n" . sprintf('[...] %s [...]', $comment->comment_content ) . "\r\n\r\n";
 		$notify_message .= __('You can see all pingbacks on this post here: ') . "\r\n";
 		$subject = sprintf( __('[%1$s] Pingback: "%2$s"'), $blogname, $post->post_title );
@@ -439,7 +439,7 @@
 	$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
 	$notify_message .= sprintf( __('Author : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
 	$notify_message .= sprintf( __('E-mail : %s'), $comment->comment_author_email ) . "\r\n";
-	$notify_message .= sprintf( __('URI    : %s'), $comment->comment_author_url ) . "\r\n";
+	$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
 	$notify_message .= sprintf( __('Whois  : http://ws.arin.net/cgi-bin/whois.pl?queryinput=%s'), $comment->comment_author_IP ) . "\r\n";
 	$notify_message .= __('Comment: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
 	$notify_message .= sprintf( __('To approve this comment, visit: %s'),  get_settings('siteurl').'/wp-admin/comment.php?action=mailapprovecomment&p='.$comment->comment_post_ID."&comment=$comment_id" ) . "\r\n";
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 3877)
+++ wp-includes/post.php	(working copy)
@@ -799,7 +799,7 @@
 // Trackback and ping functions
 //
 
-function add_ping($post_id, $uri) { // Add a URI to those already pung
+function add_ping($post_id, $uri) { // Add a URL to those already pung
 	global $wpdb;
 	$pung = $wpdb->get_var("SELECT pinged FROM $wpdb->posts WHERE ID = $post_id");
 	$pung = trim($pung);
@@ -829,7 +829,7 @@
 	return $pung;
 }
 
-function get_pung($post_id) { // Get URIs already pung for a post
+function get_pung($post_id) { // Get URLs already pung for a post
 	global $wpdb;
 	$pung = $wpdb->get_var("SELECT pinged FROM $wpdb->posts WHERE ID = $post_id");
 	$pung = trim($pung);
@@ -838,7 +838,7 @@
 	return $pung;
 }
 
-function get_to_ping($post_id) { // Get any URIs in the todo list
+function get_to_ping($post_id) { // Get any URLs in the todo list
 	global $wpdb;
 	$to_ping = $wpdb->get_var("SELECT to_ping FROM $wpdb->posts WHERE ID = $post_id");
 	$to_ping = trim($to_ping);
@@ -1094,7 +1094,7 @@
 
 		foreach ($posts as $id => $post) {
 
-			// URI => page name
+			// URL => page name
 			$uri = get_page_uri($id);
 			$attachments = $wpdb->get_results("SELECT ID, post_name, post_parent FROM $wpdb->posts WHERE post_type = 'attachment' AND post_parent = '$id'");
 			if ( $attachments ) {
Index: wp-includes/query.php
===================================================================
--- wp-includes/query.php	(revision 3877)
+++ wp-includes/query.php	(working copy)
@@ -728,7 +728,7 @@
 			$distinct = 'DISTINCT';
 		}
 
-		// Category stuff for nice URIs
+		// Category stuff for nice URLs
 
 		global $cache_categories;
 		if ('' != $q['category_name']) {
@@ -787,7 +787,7 @@
 			$whichauthor .= ')';
 		}
 
-		// Author stuff for nice URIs
+		// Author stuff for nice URLs
 
 		if ('' != $q['author_name']) {
 			if (stristr($q['author_name'],'/')) {
Index: wp-includes/rewrite.php
===================================================================
--- wp-includes/rewrite.php	(revision 3877)
+++ wp-includes/rewrite.php	(working copy)
@@ -84,7 +84,7 @@
 	$url_split = explode('#', $url);
 	$url = $url_split[0];
 
-	// Get rid of URI ?query=string
+	// Get rid of URL ?query=string
 	$url_split = explode('?', $url);
 	$url = $url_split[0];
 
Index: wp-trackback.php
===================================================================
--- wp-trackback.php	(revision 3877)
+++ wp-trackback.php	(working copy)
@@ -86,7 +86,7 @@
 
 	$dupe = $wpdb->get_results("SELECT * FROM $wpdb->comments WHERE comment_post_ID = '$comment_post_ID' AND comment_author_url = '$comment_author_url'");
 	if ( $dupe )
-		trackback_response(1, 'We already have a ping from that URI for this post.');
+		trackback_response(1, 'We already have a ping from that URL for this post.');
 
 	$commentdata = compact('comment_post_ID', 'comment_author', 'comment_author_email', 'comment_author_url', 'comment_content', 'comment_type');
 
Index: xmlrpc.php
===================================================================
--- xmlrpc.php	(revision 3877)
+++ xmlrpc.php	(working copy)
@@ -328,7 +328,7 @@
 	    return new IXR_Error(401, 'Sorry, this user can not edit the template.');
 	  }
 
 	  /* warning: here we make the assumption that the weblog's URI is on the same server */
 	  $filename = get_settings('home') . '/';
 	  $filename = preg_replace('#https?://.+?/#', $_SERVER['DOCUMENT_ROOT'].'/', $filename);
 
@@ -363,7 +363,7 @@
 	    return new IXR_Error(401, 'Sorry, this user can not edit the template.');
 	  }
 
 	  /* warning: here we make the assumption that the weblog's URI is on the same server */
 	  $filename = get_settings('home') . '/';
 	  $filename = preg_replace('#https?://.+?/#', $_SERVER['DOCUMENT_ROOT'].'/', $filename);
 
@@ -1153,24 +1153,24 @@
 			}
 		} else {
 			// TODO: Attempt to extract a post ID from the given URL
-	  		return new IXR_Error(33, 'The specified target URI cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
+	  		return new IXR_Error(33, 'The specified target URL cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
 		}
 		$post_ID = (int) $post_ID;
 
 
-		logIO("O","(PB) URI='$pagelinkedto' ID='$post_ID' Found='$way'");
+		logIO("O","(PB) URL='$pagelinkedto' ID='$post_ID' Found='$way'");
 
 		$post = get_post($post_ID);
 
 		if ( !$post ) // Post_ID not found
-	  		return new IXR_Error(33, 'The specified target URI cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
+	  		return new IXR_Error(33, 'The specified target URL cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
 
 		if ( $post_ID == url_to_postid($pagelinkedfrom) )
-			return new IXR_Error(0, 'The source URI and the target URI cannot both point to the same resource.');
+			return new IXR_Error(0, 'The source URL and the target URL cannot both point to the same resource.');
 
 		// Check if pings are on
 		if ( 'closed' == $post->ping_status )
-	  		return new IXR_Error(33, 'The specified target URI cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
+	  		return new IXR_Error(33, 'The specified target URL cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
 
 		// Let's check that the remote site didn't already pingback this entry
 		$result = $wpdb->get_results("SELECT * FROM $wpdb->comments WHERE comment_post_ID = '$post_ID' AND comment_author_url = '$pagelinkedfrom'");
@@ -1184,7 +1184,7 @@
 		// Let's check the remote site
 		$linea = wp_remote_fopen( $pagelinkedfrom );
 		if ( !$linea )
-	  		return new IXR_Error(16, 'The source URI does not exist.');
+	  		return new IXR_Error(16, 'The source URL does not exist.');
 
 		// Work around bug in strip_tags():
 		$linea = str_replace('<!DOC', '<DOC', $linea);
@@ -1219,7 +1219,7 @@
 		}
 
 		if ( empty($context) ) // URL pattern not found
-			return new IXR_Error(17, 'The source URI does not contain a link to the target URI, and so cannot be used as a source.');
+			return new IXR_Error(17, 'The source URL does not contain a link to the target URL, and so cannot be used as a source.');
 
 		$pagelinkedfrom = preg_replace('#&([^amp\;])#is', '&amp;$1', $pagelinkedfrom);
 
@@ -1257,14 +1257,14 @@
 		$post_ID = url_to_postid($url);
 		if (!$post_ID) {
 			// We aren't sure that the resource is available and/or pingback enabled
-	  		return new IXR_Error(33, 'The specified target URI cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
+	  		return new IXR_Error(33, 'The specified target URL cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
 		}
 
 		$actual_post = wp_get_single_post($post_ID, ARRAY_A);
 
 		if (!$actual_post) {
 			// No such post = resource not found
-	  		return new IXR_Error(32, 'The specified target URI does not exist.');
+	  		return new IXR_Error(32, 'The specified target URL does not exist.');
 		}
 
 		$comments = $wpdb->get_results("SELECT comment_author_url, comment_content, comment_author_IP, comment_type FROM $wpdb->comments WHERE comment_post_ID = $post_ID");
@@ -328,7 +328,7 @@
 	  }
 
-	  /* warning: here we make the assumption that the weblog's URI is on the same server */
+	  /* warning: here we make the assumption that the weblog's URL is on the same server */
 	  $filename = get_settings('home') . '/';
 	  $filename = preg_replace('#https?://.+?/#', $_SERVER['DOCUMENT_ROOT'].'/', $filename);
@@ -363,7 +363,7 @@
 	  }
 
-	  /* warning: here we make the assumption that the weblog's URI is on the same server */
+	  /* warning: here we make the assumption that the weblog's URL is on the same server */
 	  $filename = get_settings('home') . '/';
 	  $filename = preg_replace('#https?://.+?/#', $_SERVER['DOCUMENT_ROOT'].'/', $filename);
